connect to tlma%

create procedure ADM.DROP_VIEW_IF_EXISTS(in VIEW_NAME char(100))
	begin
	declare STMT char(100);
	declare MSG char(20);
	
	declare continue handler for sqlstate '42704' set MSG = 'ok';
	
	set STMT = 'DROP VIEW ' concat VIEW_NAME;
	prepare S1 from STMT;
	execute S1;
	end%

CALL ADM.DROP_VIEW_IF_EXISTS('CUSTOM.AGENT_V')%

create view CUSTOM.AGENT_V
(
	ID,
	HOSTNAME,
	IP_ADDRESS,
	VERSION,
	OS_NAME,
	OS_VERSION,
	PLUGIN_TIME,
	SCAN_TIME,
	LOCAL_SCAN_TIME,
	ACTIVE,
	NODE_ID,
	SCAN_GROUP_ID,
	SECURITY_LEVEL,
	INV_SYNCED,
	CUSTOM_DATA1,
	CUSTOM_DATA2,
	CUSTOM_DATA3,
	FULL_HWSCAN_TIME,
	FULL_HWSCAN_LOCAL_TIME,
	CATALOG_VERSION,
	DELETED_TIME,
	PACKET_IP_ADDRESS
)
as
    select
	A.ID,
	A.HOSTNAME,
	A.IP_ADDRESS,
	A.VERSION,
	A.OS_NAME,
	A.OS_VERSION,
	A.PLUGIN_TIME,
	A.SCAN_TIME,
	A.LOCAL_SCAN_TIME,
	A.ACTIVE,
	A.NODE_ID,
	A.DIVISION_ID,
	A.SECURITY_LEVEL,
	A.INV_SYNCED,
	A.CUSTOM_DATA1,
	A.CUSTOM_DATA2,
	A.CUSTOM_DATA3,
	A.HWSCAN_SERVER_TIME,
	A.HWSCAN_TIME,
	A.CATALOG_TIME,
    cast(null as timestamp),
    A.PACKET_IP_ADDRESS
    from
      ADM.AGENT A
    union all
    select
	A.ID,
	A.HOSTNAME,
	A.IP_ADDRESS,
	A.VERSION,
	A.OS_NAME,
	A.OS_VERSION,
	A.PLUGIN_TIME,
	A.SCAN_TIME,
	CAST(null as timestamp),
	0,
	A.NODE_ID,
	A.DIVISION_ID,
	A.SECURITY_LEVEL,
	CAST(null as integer),
	A.CUSTOM_DATA1,
	A.CUSTOM_DATA2,
	A.CUSTOM_DATA3,
	CAST(null as timestamp),
	CAST(null as timestamp),
	A.CATALOG_TIME,
	A.DELETED_TIME,
	CAST(null as varchar(39))
    from
      ADM.AGENT_DELETED A%

grant select on CUSTOM.AGENT_V to user TLMSRV%
      
comment on table CUSTOM.AGENT_V is 'Agents which are deployed with this server instance'%
comment on column CUSTOM.AGENT_V.HOSTNAME is 'System host name (e.g. omega.ibm.com)'%
comment on column CUSTOM.AGENT_V.IP_ADDRESS is 'Network IP address'%
comment on column CUSTOM.AGENT_V.VERSION is 'Version of the agent that is installed'%
comment on column CUSTOM.AGENT_V.OS_NAME is 'Operating system name (Unix, Windows, OS/400)'%
comment on column CUSTOM.AGENT_V.OS_VERSION is 'Operating system version (e.g. 2.1, NT4, 2000)'%
comment on column CUSTOM.AGENT_V.PLUGIN_TIME is 'Date and time of the last agent plug-in or update'%
comment on column CUSTOM.AGENT_V.SCAN_TIME is 'Date and time of the last available software scan'%
comment on column CUSTOM.AGENT_V.LOCAL_SCAN_TIME is 'Agent local date and time of the last available software scan'%
comment on column CUSTOM.AGENT_V.ACTIVE is 'If true, the agent is active'%
comment on column CUSTOM.AGENT_V.NODE_ID is 'External key to NODE_V view'%
comment on column CUSTOM.AGENT_V.SCAN_GROUP_ID is 'External key to SCAN_GROUP_V'%
comment on column CUSTOM.AGENT_V.SECURITY_LEVEL is '0=HTTP; 1=HTTPS (server authentication); 2=HTTPS (server & agent authentication)'%
comment on column CUSTOM.AGENT_V.INV_SYNCED is '0 = Inventory out of sync; 1 = Inventory synced.'%
comment on column CUSTOM.AGENT_V.CUSTOM_DATA1 is 'Custom data'%
comment on column CUSTOM.AGENT_V.CUSTOM_DATA2 is 'Custom data'%
comment on column CUSTOM.AGENT_V.CUSTOM_DATA3 is 'Custom data'%
comment on column CUSTOM.AGENT_V.FULL_HWSCAN_TIME is 'Date and time of the last available full hw scan'%
comment on column CUSTOM.AGENT_V.FULL_HWSCAN_LOCAL_TIME is 'Agent local date and time of the last available full hw scan'%
comment on column CUSTOM.AGENT_V.CATALOG_VERSION is 'Date and time of the last catalog update'%
comment on column CUSTOM.AGENT_V.DELETED_TIME is 'Timestamp of agents deletion'%
comment on column CUSTOM.AGENT_V.ID is 'Synthetic identifier'%
comment on column CUSTOM.AGENT_V.PACKET_IP_ADDRESS is 'Source IP address of last received packet. It can be address of agent or some proxy between agent and server.'%

drop procedure ADM.DROP_VIEW_IF_EXISTS%
      
disconnect current%