-- ****************************************************************************
-- * Licensed Materials - Property of IBM
-- * 5724-T40 IBM License Metric Tool
-- * 5724-S94 IBM Tivoli Asset Discovery for Distributed
-- *
-- * (C) Copyright IBM Corp. 2012.  All Rights Reserved.
-- *
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- ****************************************************************************

-- procedure to delete index
create procedure ADM.DROP_INDEX_IF_EXISTS(in INDEX_NAME char(100))
	begin
	declare STMT char(250);
	declare MSG char(20);
	
	declare continue handler for sqlstate '42704' set MSG = 'ok';
	
	set STMT = 'DROP INDEX ' concat INDEX_NAME;
	prepare S1 from STMT;
	execute S1;
	end%

create procedure ADM.DROP_FUNCTION_IF_EXISTS(in FUNCTION_NAME char(100))
	begin
	declare STMT char(100);
	declare MSG char(20);
	
	declare continue handler for sqlstate '42704' set MSG = 'ok';
	
	set STMT = 'DROP FUNCTION ' concat FUNCTION_NAME;
	prepare S1 from STMT;
	execute S1;
	end%

create procedure ADM.DROP_TRIGGER_IF_EXISTS(in TRIGGER_NAME char(100))
	begin
	declare STMT char(100);
	declare MSG char(20);
	
	declare continue handler for sqlstate '42704' set MSG = 'ok';
	
	set STMT = 'DROP TRIGGER ' concat TRIGGER_NAME;
	prepare S1 from STMT;
	execute S1;
	end%	
	
-------------------------------------------------------------------------------  
-- ADM.AGENT table
-------------------------------------------------------------------------------
call ADM.DROP_INDEX_IF_EXISTS('ADM.AGENT_I3')%

CREATE UNIQUE INDEX ADM.AGENT_I3 ON ADM.AGENT 
(
	"ID" ASC
) 
INCLUDE 
(
	"CREATION_TIME",
   	"SCAN_TIME", 
   	"VERSION"
) 
ALLOW REVERSE SCANS%

runstats on table ADM.AGENT and indexes all%

-------------------------------------------------------------------------------  
-- ADM.AGENT_DELETED table
-------------------------------------------------------------------------------
call ADM.DROP_INDEX_IF_EXISTS('ADM.AGENT_DEL_I4')%

CREATE INDEX ADM.AGENT_DEL_I4 ON ADM.AGENT_DELETED
(
	"ID" ASC, 
	"DELETED_TIME" ASC, 
	"CREATION_TIME" ASC,
   	"SCAN_TIME" ASC, 
   	"VERSION" ASC
) 
ALLOW REVERSE SCANS%

runstats on table ADM.AGENT_DELETED and indexes all%

-------------------------------------------------------------------------------  
-- ADM.AGGREGATION_SKIPPED_AGENT table
-------------------------------------------------------------------------------
call ADM.DROP_INDEX_IF_EXISTS('ADM.AGGR_S_A_I1')%

CREATE INDEX ADM.AGGR_S_A_I1 ON ADM.AGGREGATION_SKIPPED_AGENT
(
	"AGENT_ID" ASC, 
	"END_DATE" ASC
) 
ALLOW REVERSE SCANS%

runstats on table ADM.AGGREGATION_SKIPPED_AGENT and indexes all%

-------------------------------------------------------------------------------  
-- ADM.AGT_VM_REL table
-------------------------------------------------------------------------------
call ADM.DROP_INDEX_IF_EXISTS('ADM.AGT_VM_REL_I1')%

CREATE INDEX ADM.AGT_VM_REL_I1 ON ADM.AGT_VM_REL
(
	"END_TIME" ASC, 
	"START_TIME" DESC
) 
ALLOW REVERSE SCANS%

call ADM.DROP_INDEX_IF_EXISTS('ADM.AGT_VM_REL_I2')%

CREATE INDEX ADM.AGT_VM_REL_I2 ON ADM.AGT_VM_REL
(
	"AGENT_ID" ASC, 
	"END_TIME" ASC, 
	"START_TIME" ASC,
   	"VM_ID" ASC
) 
ALLOW REVERSE SCANS%

runstats on table ADM.AGT_VM_REL and indexes all%

-------------------------------------------------------------------------------  
-- ADM.CONTROL table
-------------------------------------------------------------------------------
call ADM.DROP_INDEX_IF_EXISTS('ADM.CONTROL_I1')%

CREATE UNIQUE INDEX ADM.CONTROL_I1 ON ADM.CONTROL
(
	"NAME" ASC
) 
INCLUDE 
(
	"VALUE"
)
ALLOW REVERSE SCANS%

runstats on table ADM.CONTROL and indexes all%

-------------------------------------------------------------------------------  
-- ADM.VM table
-------------------------------------------------------------------------------
call ADM.DROP_INDEX_IF_EXISTS('ADM.VM_UI2')%

CREATE UNIQUE INDEX ADM.VM_UI2 ON ADM.VM 
(
	"ID" ASC
) 
INCLUDE 
(
	"NODE_ID"
)
ALLOW REVERSE SCANS%

runstats on table ADM.VM and indexes all%

-------------------------------------------------------------------------------  
-- ADM.PVU_PROD_INV table
-------------------------------------------------------------------------------
call ADM.DROP_INDEX_IF_EXISTS('ADM.PVU_PRDINV_I1')%

CREATE INDEX ADM.PVU_PRDINV_I1 ON ADM.PVU_PROD_INV
(
	"AGENT_ID" ASC, 
	"TYPE" ASC, 
	"END_TIME" ASC, 
	"START_TIME" ASC
) 
ALLOW REVERSE SCANS%

call ADM.DROP_INDEX_IF_EXISTS('ADM.PVU_PRDINV_I2')%

CREATE INDEX ADM.PVU_PRDINV_I2 ON ADM.PVU_PROD_INV
(
	"AGENT_ID" ASC, 
	"TYPE" ASC, 
	"END_TIME" ASC, 
	"START_TIME" ASC, 
	"PRODUCT_ID" ASC, 
	"COMPONENT_ID" ASC, 
	"SCOPE_ID" ASC, 
	"IS_REMOTE" ASC, 
	"LINK_ID" ASC
) 
ALLOW REVERSE SCANS%

runstats on table ADM.PVU_PROD_INV and indexes all%

-------------------------------------------------------------------------------  
-- ADM.STG_PROD_INV table
-------------------------------------------------------------------------------
call ADM.DROP_INDEX_IF_EXISTS('ADM.STG_PRDINV_I1')%

CREATE INDEX ADM.STG_PRDINV_I1 ON ADM.STG_PROD_INV
(
	"AGENT_ID" ASC, 
	"TYPE" ASC, 
	"END_TIME" ASC, 
	"START_TIME" ASC, 
	"PRODUCT_ID" ASC, 
	"COMPONENT_ID" ASC, 
	"SCOPE_ID" ASC, 
	"IS_REMOTE" ASC, 
	"LINK_ID" ASC
) 
ALLOW REVERSE SCANS%

runstats on table ADM.STG_PROD_INV and indexes all%

-------------------------------------------------------------------------------  
-- ADM.PROD_INV table
-------------------------------------------------------------------------------

call ADM.DROP_INDEX_IF_EXISTS('ADM.PROD_INV_CID')%

CREATE INDEX ADM.PROD_INV_CID ON ADM.PROD_INV
(
	"COMPONENT_ID" ASC,
	"END_TIME" ASC
) 
ALLOW REVERSE SCANS%

call ADM.DROP_INDEX_IF_EXISTS('ADM.PROD_INV_PID')%

CREATE INDEX ADM.PROD_INV_PID ON ADM.PROD_INV
(
	"PRODUCT_ID" ASC,
	"END_TIME" ASC
) 
ALLOW REVERSE SCANS%


runstats on table ADM.PROD_INV and indexes all%

-------------------------------------------------------------------------------  
-- ADM.INST_NATIVE_SW table
-------------------------------------------------------------------------------

call ADM.DROP_INDEX_IF_EXISTS('ADM.INS_NID_IDX')%

CREATE INDEX ADM.INS_NID_IDX ON ADM.INST_NATIVE_SW
(
	"NATIVE_ID" ASC
) 
ALLOW REVERSE SCANS%

runstats on table ADM.INST_NATIVE_SW and indexes all%

-------------------------------------------------------------------------------  
-- fixes after F36707.2
-------------------------------------------------------------------------------

call ADM.DROP_TRIGGER_IF_EXISTS('ADM.VM_TR3')%
call ADM.DROP_TRIGGER_IF_EXISTS('ADM.VM_TR4')%
call ADM.DROP_FUNCTION_IF_EXISTS('adm.getUUIDForLayer')%

CREATE FUNCTION adm.getUUIDForLayer( layer_name VARCHAR(256) , type smallint)
RETURNS VARCHAR(256)
CONTAINS SQL
NO EXTERNAL ACTION
DETERMINISTIC
BEGIN ATOMIC
	DECLARE pos INTEGER;

	if ( type not in (0,2,3) ) then
		return null;
	end if;
	if (type in (2,3)) then
		return lower(layer_name);
	end if;
	if (layer_name like 'TLM_VM_VMware%') then
		return lower(substr(layer_name, 15));
	end if;
	if (layer_name like 'TLM_VM_KVM%') then
		return lower(substr(layer_name, 12));
	end if;
	if (layer_name like 'TLM_VM_%') then
		return lower(substr(layer_name, 8));
	end if;
	return null;
END%

GRANT EXECUTE ON FUNCTION adm.getUUIDForLayer(VARCHAR(256),smallint) to user TLMSRV%

create trigger ADM.VM_TR3
    after insert on ADM.VM
    referencing new as NEW for each row mode db2sql
    when (
        (NEW.TYPE in (2,3)) OR
        (NEW.TYPE = 0 AND NEW.LAYER_NAME like 'TLM_VM_%')
    )
    insert into ADM.VIRTUAL_VM_UUID (
    	vm_id,
        uuid)
    values (
        NEW.ID,
        adm.getUUIDForLayer(NEW.LAYER_NAME, NEW.TYPE)
)%

create trigger ADM.VM_TR4
    after delete on ADM.VM
    referencing old as OLD for each row mode db2sql
    delete from ADM.VIRTUAL_VM_UUID
    WHERE VM_ID = OLD.ID%

insert into ADM.VIRTUAL_VM_UUID 
	select id, adm.getUUIDForLayer(LAYER_NAME, type) from adm.vm 
	where type = 2%

drop procedure ADM.DROP_INDEX_IF_EXISTS%
drop procedure ADM.DROP_FUNCTION_IF_EXISTS%
drop procedure ADM.DROP_TRIGGER_IF_EXISTS%