-- ****************************************************************************
-- * Licensed Materials - Property of IBM
-- * 5724-T40 IBM License Metric Tool
-- * 5724-S94 IBM Tivoli Asset Discovery for Distributed
-- *
-- * (C) Copyright IBM Corp. 2012.  All Rights Reserved.
-- *
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- ****************************************************************************

connect to tlma%

create procedure ADM.DROP_TABLE_IF_EXISTS(in TABLE_NAME char(100))
	begin
	declare STMT char(100);
	declare MSG char(20);
	
	declare continue handler for sqlstate '42704' set MSG = 'ok';
	
	set STMT = 'DROP TABLE ' concat TABLE_NAME;
	prepare S1 from STMT;
	execute S1;
	end%
	
create procedure ADM.DROP_FUNCTION_IF_EXISTS(in FUNCTION_NAME char(100))
	begin
	declare STMT char(100);
	declare MSG char(20);
	
	declare continue handler for sqlstate '42704' set MSG = 'ok';
	
	set STMT = 'DROP FUNCTION ' concat FUNCTION_NAME;
	prepare S1 from STMT;
	execute S1;
	end%

create procedure ADM.DROP_TRIGGER_IF_EXISTS(in TRIGGER_NAME char(100))
	begin
	declare STMT char(100);
	declare MSG char(20);
	
	declare continue handler for sqlstate '42704' set MSG = 'ok';
	
	set STMT = 'DROP TRIGGER ' concat TRIGGER_NAME;
	prepare S1 from STMT;
	execute S1;
	end%

create procedure ADM.DROP_INDEX_IF_EXISTS(in INDEX_NAME char(100))
	begin
	declare STMT char(250);
	declare MSG char(20);
	
	declare continue handler for sqlstate '42704' set MSG = 'ok';
	
	set STMT = 'DROP INDEX ' concat INDEX_NAME;
	prepare S1 from STMT;
	execute S1;
	end%

call ADM.DROP_TABLE_IF_EXISTS('ADM.VIRTUAL_VM_UUID')%

create table ADM.VIRTUAL_VM_UUID (
	vm_id bigint not null, 
	uuid varchar(192)
)%

alter table ADM.VIRTUAL_VM_UUID add constraint VM_UUID_PK primary key
(
    VM_ID
)%

create index ADM.VM_UUID_IDX1 on ADM.VIRTUAL_VM_UUID
(
    VM_ID,
    UUID
)%

grant select, insert, delete, update on ADM.VIRTUAL_VM_UUID to user TLMSRV%

call ADM.DROP_FUNCTION_IF_EXISTS('adm.getUUIDForLayer')%

CREATE FUNCTION adm.getUUIDForLayer( layer_name VARCHAR(256) , type smallint)
RETURNS VARCHAR(256)
CONTAINS SQL
NO EXTERNAL ACTION
DETERMINISTIC
BEGIN ATOMIC
	DECLARE pos INTEGER;

	if ( type not in (0,3) ) then
		return null;
	end if;
	if (type = 3) then
		return lower(layer_name);
	end if;
	if (layer_name like 'TLM_VM_VMware%') then
		return lower(substr(layer_name, 15));
	end if;
	if (layer_name like 'TLM_VM_KVM%') then
		return lower(substr(layer_name, 12));
	end if;
	if (layer_name like 'TLM_VM_%') then
		return lower(substr(layer_name, 8));
	end if;
	return null;
END%

GRANT EXECUTE ON FUNCTION adm.getUUIDForLayer(VARCHAR(256),smallint) to user TLMSRV%

call ADM.DROP_TRIGGER_IF_EXISTS('ADM.VM_TR3')%

create trigger ADM.VM_TR3
    after insert on ADM.VM
    referencing new as NEW for each row mode db2sql
    when (
        (NEW.TYPE = 3) OR
        (NEW.TYPE = 0 AND NEW.LAYER_NAME like 'TLM_VM_%')
    )
    insert into ADM.VIRTUAL_VM_UUID (
    	vm_id,
        uuid)
    values (
        NEW.ID,
        adm.getUUIDForLayer(NEW.LAYER_NAME, NEW.TYPE)
)%

call ADM.DROP_TRIGGER_IF_EXISTS('ADM.VM_TR4')%

create trigger ADM.VM_TR4
    after delete on ADM.VM
    referencing old as OLD for each row mode db2sql
    delete from ADM.VIRTUAL_VM_UUID
    WHERE VM_ID = OLD.ID%

insert into ADM.VIRTUAL_VM_UUID 
	select id, adm.getUUIDForLayer(LAYER_NAME, type) from adm.vm 
	where type = 3%
	
insert into ADM.VIRTUAL_VM_UUID  
	select id, adm.getUUIDForLayer(LAYER_NAME, type) from adm.vm 
	where LAYER_NAME like 'TLM_VM_%' and type = 0%

runstats on table ADM.VIRTUAL_VM_UUID and indexes all%

call ADM.DROP_INDEX_IF_EXISTS('ADM.VM_REL_I1')%

create index ADM.VM_REL_I1 ON ADM.AGT_VM_REL
(
	"END_TIME" ASC,
	"START_TIME" DESC
) 
ALLOW REVERSE SCANS%

call ADM.DROP_INDEX_IF_EXISTS('ADM.VM_REL_I2')%

create index ADM.VM_REL_I2 ON ADM.AGT_VM_REL
(
	"VM_ID" ASC,
	"END_TIME" ASC,	
	"START_TIME" ASC,
	"AGENT_ID" ASC
) 
ALLOW REVERSE SCANS%

runstats on table ADM.AGT_VM_REL and indexes all%

insert into lic.CONTROL_VALUES (CONTROL_KEY, CONTROL_VALUE, CONTROL_VALUE_TYPE, CONTROL_VALUE_MIN, 
CONTROL_VALUE_MAX, CONTROL_VALUE_ENUM, CONTROL_HIDDEN, CONTROL_UNITS) 
values ('checkUniquenessOfManagersIP', 'true', 2, null, null, 'false,true',1,'true/false')%

insert into lic.CONTROL_VALUES (CONTROL_KEY, CONTROL_VALUE, CONTROL_VALUE_TYPE, CONTROL_VALUE_MIN, 
CONTROL_VALUE_MAX, CONTROL_VALUE_ENUM, CONTROL_HIDDEN, CONTROL_UNITS) 
values ('storeHwDataForAllVMManagerNodes', 'false', 2, null, null, 'false,true',0,'true/false')%

drop procedure ADM.DROP_TABLE_IF_EXISTS%
drop procedure ADM.DROP_FUNCTION_IF_EXISTS%
drop procedure ADM.DROP_TRIGGER_IF_EXISTS%
drop procedure ADM.DROP_INDEX_IF_EXISTS%

disconnect tlma%

